@@ -626,14 +626,15 @@ def genpdf(maadstoken,maads_rest_url,pkey,urltomaadsserver,savetofolder,username
     except Exception as e:  
       return "ERROR: Retrieving PDF: %s" % e 
 
-def algoinfo(maadstoken,maads_rest_url,pkey,username='',passw='',company='',email=''):
+def algoinfo(maadstoken,maads_rest_url,pkey,isrest=0,username='',passw='',company='',email=''):
     files = {'mode':'algoinfo',        
         'username': username,
         'password': passw,
         'company': company,
         'email': email,
         'maadstoken':maadstoken,     
-        'pkey':pkey     
+        'pkey':pkey,
+        'isrest':isrest     
       }
 
     r = requests.post(maads_rest_url, files)
